import 'package:flutter/material.dart';
import 'package:furman_now/src/screens/events/index.dart';
import 'package:furman_now/src/screens/home/index.dart';
import 'package:furman_now/src/screens/info/index.dart';
import 'package:furman_now/src/screens/map/index.dart';
import 'package:furman_now/src/screens/student_id/index.dart';
import 'package:furman_now/src/utils/theme.dart';
import 'package:navbar_router/navbar_router.dart';

class App extends StatelessWidget {
  const App({super.key});

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Furman Now!',
      home: const MainPage(),
      theme: myFurmanTheme,
    );
  }
}

class MainPage extends StatefulWidget {
  const MainPage({Key? key}) : super(key: key);

  @override
  State<MainPage> createState() => _MainPageState();
}

class _MainPageState extends State<MainPage> {
  List<NavbarItem> items = [
    NavbarItem(Icons.home_outlined, 'Home', backgroundColor: colors[0]),
    NavbarItem(Icons.map_outlined, 'Map', backgroundColor: colors[0]),
    NavbarItem(Icons.person_outline, 'Meal ID', backgroundColor: colors[0]),
    NavbarItem(Icons.calendar_month_outlined, 'Events', backgroundColor: colors[0]),
    NavbarItem(Icons.info_outline, 'Info', backgroundColor: colors[0]),
  ];

  final Map<int, Map<String, Widget>> _routes = const {
    0: {
      '/': HomeScreen(),
      // FeedDetail.route: FeedDetail(),
    },
    1: {
      '/': MapScreen(),
      // ProductDetail.route: ProductDetail(),
      // ProductComments.route: ProductComments(),
    },
    2: {
      '/': StudentIdScreen(),
      // ProductDetail.route: ProductDetail(),
      // ProductComments.route: ProductComments(),
    },
    3: {
      '/': EventsScreen(),
      // ProfileEdit.route: ProfileEdit(),
    },
    4: {
      '/': InfoScreen(),
      // ProfileEdit.route: ProfileEdit(),
    },
  };

  void showSnackBar() {
    ScaffoldMessenger.of(context).showSnackBar(
      const SnackBar(
        behavior: SnackBarBehavior.floating,
        duration: Duration(milliseconds: 600),
        margin: EdgeInsets.only(
            bottom: kBottomNavigationBarHeight + 2, right: 2, left: 2),
        content: Text('Tap back button again to exit'),
      ),
    );
  }

  void hideSnackBar() {
    ScaffoldMessenger.of(context).hideCurrentSnackBar();
  }

  DateTime oldTime = DateTime.now();
  DateTime newTime = DateTime.now();

  @override
  Widget build(BuildContext context) {
    final size = MediaQuery.of(context).size;
    return Scaffold(
      resizeToAvoidBottomInset: false,
      body: NavbarRouter(
        errorBuilder: (context) {
          return const Center(child: Text('Error 404'));
        },
        isDesktop: size.width > 600 ? true : false,
        onBackButtonPressed: (isExitingApp) {
          if (isExitingApp) {
            newTime = DateTime.now();
            int difference = newTime.difference(oldTime).inMilliseconds;
            oldTime = newTime;
            if (difference < 1000) {
              hideSnackBar();
              return isExitingApp;
            } else {
              showSnackBar();
              return false;
            }
          } else {
            return isExitingApp;
          }
        },
        destinationAnimationCurve: Curves.fastOutSlowIn,
        destinationAnimationDuration: 600,
        decoration: NavbarDecoration(
            selectedLabelTextStyle: const TextStyle(color: Colors.deepPurple),
            showUnselectedLabels: true,
            unselectedLabelTextStyle:
            const TextStyle(color: Colors.black, fontSize: 10),
            selectedIconTheme: const IconThemeData(color: Colors.deepPurple),
            isExtended: size.width > 800 ? true : false,
            navbarType: BottomNavigationBarType.fixed),
        // onChanged: (x) {
        //   debugPrint('index changed $x');
        // },
        backButtonBehavior: BackButtonBehavior.rememberHistory,
        destinations: [
          for (int i = 0; i < items.length; i++)
            DestinationRouter(
              navbarItem: items[i],
              destinations: [
                for (int j = 0; j < _routes[i]!.keys.length; j++)
                  Destination(
                    route: _routes[i]!.keys.elementAt(j),
                    widget: _routes[i]!.values.elementAt(j),
                  ),
              ],
              initialRoute: _routes[i]!.keys.first,
            ),
        ],
      ),
    );
  }
}

Future<void> navigate(BuildContext context, String route,
    {bool isDialog = false,
      bool isRootNavigator = true,
      Map<String, dynamic>? arguments}) =>
    Navigator.of(context, rootNavigator: isRootNavigator)
        .pushNamed(route, arguments: arguments);
